@@ -227,7 +227,8 @@ The ia64 says setjmp()/longjmp() buffer must be aligned at 128 bits
 #endif
 #endif
 
-#if O_LABEL_ADDRESSES && !defined(VMCODE_IS_ADDRESS)
+/* clang as of version 11 performs about 30% worse with this option */
+#if O_LABEL_ADDRESSES && !defined(VMCODE_IS_ADDRESS) && !defined(__llvm__)
 #define VMCODE_IS_ADDRESS	1
 #endif
 
@@ -291,7 +292,11 @@ typedef _sigset_t sigset_t;
 #ifdef ASSERT_H_REQUIRES_STDIO_H
 #include <stdio.h>
 #endif /*ASSERT_H_REQUIRES_STDIO_H*/
+#ifdef NO_ASSERT_H		/* see pl-assert.c */
+#define assert(c) (void)0
+#else
 #include <assert.h>
+#endif
 #include <stdlib.h>
 #include <string.h>
 #include <stddef.h>
@@ -405,10 +410,6 @@ A common basis for C keywords.
 #define unlikely(x)	(x)
 #endif
 
-#if defined(__STRICT_ANSI__) || defined(NO_ASM_NOP)
-#define ASM_NOP { static int nop; nop++; }
-#endif
-
 #ifdef DMALLOC
 #include <dmalloc.h>			/* Use www.dmalloc.com debugger */
 
@@ -476,7 +477,6 @@ them.  Descriptions:
 	skips this amount of stack.
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-#define BUFFER_RING_SIZE	16	/* foreign buffer ring (pl-fli.c) */
 #define LINESIZ			1024	/* size of a data line */
 #define MAXARITY		1024	/* arity of predicate */
 #define MINFOREIGNSIZE		32	/* Minimum term_t in foreign frame */
@@ -802,14 +802,15 @@ typedef enum
 /* See updateAlerted()
 */
 
-#define	ALERT_SIGNAL	     0x01
-#define	ALERT_GCREQ	     0x02
-#define	ALERT_PROFILE	     0x04
-#define	ALERT_EXITREQ	     0x08
-#define	ALERT_DEPTHLIMIT     0x10
-#define	ALERT_INFERENCELIMIT 0x20
-#define	ALERT_WAKEUP	     0x40
-#define	ALERT_DEBUG	     0x80
+#define	ALERT_SIGNAL	     0x001
+#define	ALERT_GCREQ	     0x002
+#define	ALERT_PROFILE	     0x004
+#define	ALERT_EXITREQ	     0x008
+#define	ALERT_DEPTHLIMIT     0x010
+#define	ALERT_INFERENCELIMIT 0x020
+#define	ALERT_WAKEUP	     0x040
+#define	ALERT_DEBUG	     0x080
+#define	ALERT_BUFFER	     0x100
 
 
 		 /*******************************
@@ -1514,9 +1515,9 @@ typedef struct definition_refs
 #define PROC_IMPORTED	 (0x0004)	/* Procedure is imported */
 
 struct procedure
-{ Definition	 definition;		/* definition of procedure */
-  unsigned short flags;			/* PROC_WEAK */
-  unsigned short source_no;		/* Source I'm assigned to */
+{ Definition	definition;		/* definition of procedure */
+  unsigned int  flags;			/* PROC_WEAK */
+  unsigned int	source_no;		/* Source I'm assigned to */
 };
 
 struct localFrame
@@ -1770,8 +1771,9 @@ struct sourceFile
 #endif
   int		magic;			/* Magic number */
   int		count;			/* number of times loaded */
-  unsigned	number_of_clauses;	/* number of clauses */
-  unsigned	index     : 24;		/* index number (1,2,...) */
+  unsigned int	number_of_clauses;	/* number of clauses */
+  unsigned int	index;			/* index number (1,2,...) */
+  unsigned int	references;		/* Reference count */
   unsigned	system     : 1;		/* system sourcefile: do not reload */
   unsigned	from_state : 1;		/* Loaded from resource DB state */
   unsigned	resource   : 1;		/* Loaded from resource DB file */
@@ -1815,6 +1817,19 @@ struct module
   gen_t		last_modified;	/* Generation I was last modified */
 };
 
+#define MENUM_TEMP	0x1	/* Also enumerate temporary modules */
+
+typedef struct module_enum
+{ TableEnum	tenum;
+  Module        current;
+  int		flags;
+} module_enum, *ModuleEnum;
+
+
+		 /*******************************
+		 *	      TRAIL		*
+		 *******************************/
+
 struct trail_entry
 { Word		address;	/* address of the variable */
 };
@@ -1949,7 +1964,6 @@ Temporary store/restore pointers to make them safe over GC/shift
 #define QidFromQuery(f)		(consTermRef(f))
 #define QID_EXPORT_WAM_TABLE	(qid_t)(-1)
 
-#define PL_ARITY_AS_SIZE
 #include "SWI-Prolog.h"
 
 
