@@ -179,6 +179,16 @@ typedef struct pl_mutex
   unsigned auto_destroy	: 1;		/* asked to destroy */
 } pl_mutex;
 
+#define ALERT_QUEUE_RD	1
+#define ALERT_QUEUE_WR	2
+
+typedef struct alert_channel
+{ int	type;				/* Type of channel */
+  union
+  { message_queue *queue;
+  } obj;
+} alert_channel;
+
 #define PL_THREAD_MAGIC 0x2737234f
 
 extern counting_mutex _PL_mutexes[];	/* Prolog mutexes */
@@ -211,9 +221,10 @@ extern counting_mutex _PL_mutexes[];	/* Prolog mutexes */
 #define L_CGCGEN       25
 #define L_EVHOOK       26
 #define L_OSDIR	       27
+#define L_ALERT	       28
 #ifdef __WINDOWS__
-#define L_DDE	       28
-#define L_CSTACK       29
+#define L_DDE	       29
+#define L_CSTACK       30
 #endif
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -274,9 +285,6 @@ countingMutexUnlock(counting_mutex *cm)
 #define LOCKMODULE(module)	countingMutexLock((module)->mutex)
 #define UNLOCKMODULE(module)	countingMutexUnlock((module)->mutex)
 
-#define LOCKSRCFILE(sf)		countingMutexLock((sf)->mutex)
-#define UNLOCKSRCFILE(sf)	countingMutexUnlock((sf)->mutex)
-
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 				Thread-local data
 
@@ -393,9 +401,15 @@ COMMON(void)	markAtomsThreadMessageQueue(PL_local_data_t *ld);
 		 *     CONDITION VARIABLES	*
 		 *******************************/
 
+#define CV_READY	0		/* was signalled */
+#define CV_MAYBE	1		/* might be signalled */
+#define CV_TIMEDOUT	2		/* timed out */
+#define CV_INTR		3		/* interrupted */
+
 #ifdef __WINDOWS__
 
-COMMON(int)	cv_timedwait(CONDITION_VARIABLE *cv,
+COMMON(int)	cv_timedwait(message_queue *queue,
+			     CONDITION_VARIABLE *cv,
 			     CRITICAL_SECTION *external_mutex,
 			     struct timespec *deadline);
 
@@ -406,7 +420,8 @@ COMMON(int)	cv_timedwait(CONDITION_VARIABLE *cv,
 
 #else
 
-COMMON(int)	cv_timedwait(pthread_cond_t *cv,
+COMMON(int)	cv_timedwait(message_queue *queue,
+			     pthread_cond_t *cv,
 			     pthread_mutex_t *external_mutex,
 			     struct timespec *deadline);
 
@@ -417,7 +432,7 @@ COMMON(int)	cv_timedwait(pthread_cond_t *cv,
 
 #endif /* __WINDOWS__ */
 
-#define cv_wait(cv, m)		cv_timedwait(cv, m, NULL)
+#define cv_wait(cv, m)		cv_timedwait(NULL, cv, m, NULL)
 
 
 #else /*O_PLMT, end of threading-stuff */
@@ -444,8 +459,6 @@ COMMON(int)	cv_timedwait(pthread_cond_t *cv,
 #define UNLOCKDYNDEF(def)
 #define LOCKMODULE(module)
 #define UNLOCKMODULE(module)
-#define LOCKSRCFILE(sf)
-#define UNLOCKSRCFILE(sf)
 
 #define acquire_ldata(ld)	(ld)
 #define release_ldata(ld)	(void)0
